==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translatorcomment>--google--
Aggancia ai punti centrali
Specificare il centro:
Specificare il centro</translatorcomment>
        <translation>Punto centrale</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translation>Punto di riferimento</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translatorcomment>--exact match--
--file: IsoProject_it.ts--
Punto finale
Obiettivo punto</translatorcomment>
        <translation>Obiettivo punto</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;Ruota</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>Opzioni Rotazione</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Numero di copie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;Cancella Originali</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;Tieni Originali</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>Copie &amp;Multiple</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>&amp;Angolo (a):</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--exact match--
--file: Mirror_it.ts--
Usa layer e gli &amp;attributi corrente</translatorcomment>
        <translation>Usa layer e gli &amp;attributi corrente</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translatorcomment>--google--
Aggancia ai punti centrali
Specificare il centro:
Specificare il centro</translatorcomment>
        <translation>Punto centrale</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translation>Punto di riferimento</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translatorcomment>--exact match--
--file: IsoProject_it.ts--
Punto finale
Obiettivo punto</translatorcomment>
        <translation>Obiettivo punto</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;Ruota</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>Opzioni Rotazione</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Numero di copie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;Cancella Originali</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;Tieni Originali</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>Copie &amp;Multiple</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>&amp;Angolo (a):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Define angle using mouse cursor</source>
        <translation>Definisci l&apos;angolo con il cursore del mouse</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--exact match--
--file: Mirror_it.ts--
Usa layer e gli &amp;attributi corrente</translatorcomment>
        <translation>Usa layer e gli &amp;attributi corrente</translation>
    </message>
</context>
</TS>
